bloritsch 2002/06/14 06:04:03
Modified: src/java/org/apache/avalon/framework/component
ComponentManager.java ComponentSelector.java
Composable.java DefaultComponentManager.java
DefaultComponentSelector.java Recomposable.java
src/java/org/apache/avalon/framework/container
ContainerUtil.java
src/java/org/apache/avalon/framework/service
ServiceManager.java Serviceable.java
src/test/org/apache/avalon/framework/component/test
DefaultComponentManagerTestCase.java
Log:
remainder of fixes
Revision Changes Path
1.8 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentManager.java
Index: ComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentManager.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- ComponentManager.java 14 Jun 2002 01:55:52 -0000 1.7
+++ ComponentManager.java 14 Jun 2002 13:04:03 -0000 1.8
@@ -80,7 +80,7 @@
* allows the <code>ComponentManager</code> to handle the End-Of-Life
Lifecycle
* events associated with the Component. Please note, that no Exceptions
* should be thrown at this point. This is to allow easy use of the
- * ComponentLocator system without having to trap Exceptions on a
release.
+ * ComponentManager system without having to trap Exceptions on a
release.
*
* @param component The Component we are releasing.
*/
1.8 +2 -2
jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentSelector.java
Index: ComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentSelector.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- ComponentSelector.java 14 Jun 2002 01:55:52 -0000 1.7
+++ ComponentSelector.java 14 Jun 2002 13:04:03 -0000 1.8
@@ -76,10 +76,10 @@
/**
* Return the <code>Component</code> when you are finished with it. This
- * allows the <code>ComponentManager</code> to handle the End-Of-Life
Lifecycle
+ * allows the <code>ComponentSelector</code> to handle the End-Of-Life
Lifecycle
* events associated with the Component. Please note, that no Exceptions
* should be thrown at this point. This is to allow easy use of the
- * ComponentLocator system without having to trap Exceptions on a
release.
+ * ComponentSelector system without having to trap Exceptions on a
release.
*
* @param component The Component we are releasing.
*/
1.7 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/Composable.java
Index: Composable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/Composable.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Composable.java 14 Jun 2002 01:55:52 -0000 1.6
+++ Composable.java 14 Jun 2002 13:04:03 -0000 1.7
@@ -28,7 +28,7 @@
public interface Composable
{
/**
- * Pass the <code>ComponentLocator</code> to the <code>composer</code>.
+ * Pass the <code>ComponentManager</code> to the <code>composer</code>.
* The <code>Composable</code> implementation should use the specified
* <code>ComponentManager</code> to acquire the components it needs for
* execution.
1.12 +9 -9
jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentManager.java
Index: DefaultComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentSelector.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- DefaultComponentSelector.java 14 Jun 2002 01:55:52 -0000 1.9
+++ DefaultComponentSelector.java 14 Jun 2002 13:04:03 -0000 1.10
@@ -119,7 +119,7 @@
if( m_readOnly )
{
throw new IllegalStateException
- ( "ComponentLocator is read only and can not be modified" );
+ ( "ComponentSelector is read only and can not be modified" );
}
}
}
1.8 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/Recomposable.java
Index: Recomposable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/Recomposable.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- Recomposable.java 14 Jun 2002 01:55:52 -0000 1.7
+++ Recomposable.java 14 Jun 2002 13:04:03 -0000 1.8
@@ -21,7 +21,7 @@
* The <code>Composable</code> implementation should use the specified
* <code>ComponentManager</code> to acquire the components it needs for
* execution. It should also drop references to any components it
- * retrieved from old ComponentLocator.
+ * retrieved from old ComponentManager.
*
* @param componentManager The <code>ComponentManager</code> which this
* <code>Composable</code> uses.
1.3 +5 -5
jakarta-avalon/src/java/org/apache/avalon/framework/container/ContainerUtil.java
Index: ContainerUtil.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/container/ContainerUtil.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- ContainerUtil.java 14 Jun 2002 01:55:52 -0000 1.2
+++ ContainerUtil.java 14 Jun 2002 13:04:03 -0000 1.3
@@ -118,7 +118,7 @@
* implement Composable.
* @throws ComponentException if there is a problem servicing object
* @throws IllegalArgumentException if the object is Servicable but
- * ComponentLocator is null
+ * ServiceManager is null
*/
public static void service( final Object object,
final ServiceManager serviceManager )
@@ -128,7 +128,7 @@
{
if( null == serviceManager )
{
- final String message = "serviceManager is null";
+ final String message = "ServiceManager is null";
throw new IllegalArgumentException( message );
}
( (Serviceable)object ).service( serviceManager );
@@ -140,7 +140,7 @@
* [EMAIL PROTECTED] Composable} interface.
*
* @param object the object to compose
- * @param componentManager the ComponentLocator object to use for object.
+ * @param componentManager the ComponentManager object to use for object.
* May be null in which case the specified object must not
* implement Composable.
* @throws ComponentException if there is a problem composing object
@@ -148,7 +148,7 @@
* which components will be supplied with Components. Please
* Use service() from Composable instead.
* @throws IllegalArgumentException if the object is Composable but
- * ComponentLocator is null
+ * ComponentManager is null
*/
public static void compose( final Object object,
final ComponentManager componentManager )
1.5 +3 -3
jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceManager.java
Index: ServiceManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceManager.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- ServiceManager.java 14 Jun 2002 01:55:52 -0000 1.4
+++ ServiceManager.java 14 Jun 2002 13:04:03 -0000 1.5
@@ -38,7 +38,7 @@
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
* @version 1.0
- * @see org.apache.avalon.framework.service.Composable
+ * @see org.apache.avalon.framework.service.Serviceable
* @see org.apache.avalon.framework.service.ServiceSelector
*
*/
@@ -63,7 +63,7 @@
*
* @param role The role name of the <code>Object</code> to retrieve.
* @return an <code>Object</code> value
- * @throws ComponentException if an error occurs
+ * @throws ServiceException if an error occurs
*/
Object lookup( String role )
throws ServiceException;
@@ -81,7 +81,7 @@
* allows the <code>ServiceManager</code> to handle the End-Of-Life
Lifecycle
* events associated with the <code>Object</code>. Please note, that no
* Exception should be thrown at this point. This is to allow easy use
of the
- * ComponentLocator system without having to trap Exceptions on a
release.
+ * ServiceManager system without having to trap Exceptions on a release.
*
* @param object The <code>Object</code> we are releasing.
*/
1.7 +9 -9
jakarta-avalon/src/java/org/apache/avalon/framework/service/Serviceable.java
Index: Serviceable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/Serviceable.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Serviceable.java 14 Jun 2002 01:55:52 -0000 1.6
+++ Serviceable.java 14 Jun 2002 13:04:03 -0000 1.7
@@ -13,11 +13,11 @@
* but on behavioral interfaces.
* <br />
*
- * The contract surrounding a <code>Composable</code> is that it is a user.
- * The <code>Composable</code> is able to use <code>Object</code>s managed
+ * The contract surrounding a <code>Serviceable</code> is that it is a user.
+ * The <code>Serviceable</code> is able to use <code>Object</code>s managed
* by the <code>ServiceManager</code> it was initialized with. As part
* of the contract with the system, the instantiating entity must call
- * the <code>compose</code> method before the <code>Composable</code>
+ * the <code>service</code> method before the <code>Serviceable</code>
* can be considered valid.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Federico Barbieri</a>
@@ -26,20 +26,20 @@
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
* @version 1.0
- * @see org.apache.avalon.framework.service.ComponentLocator
+ * @see org.apache.avalon.framework.service.ServiceManager
*
*/
public interface Serviceable
{
/**
- * Pass the <code>ComponentManager</code> to the <code>Composable</code>.
- * The <code>Composable</code> implementation should use the specified
- * <code>ComponentManager</code> to acquire the components it needs for
+ * Pass the <code>ServiceManager</code> to the <code>Serviceable</code>.
+ * The <code>Serviceable</code> implementation should use the specified
+ * <code>ServiceManager</code> to acquire the components it needs for
* execution.
*
* @param manager The <code>ServiceManager</code> which this
- * <code>Composable</code> uses.
- * @throws ComponentException if an error occurs
+ * <code>Serviceable</code> uses.
+ * @throws ServiceException if an error occurs
*/
void service( ServiceManager manager )
throws ServiceException;
1.4 +1 -1
jakarta-avalon/src/test/org/apache/avalon/framework/component/test/DefaultComponentManagerTestCase.java
Index: DefaultComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentManager.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- DefaultComponentManager.java 14 Jun 2002 01:55:52 -0000 1.11
+++ DefaultComponentManager.java 14 Jun 2002 13:04:03 -0000 1.12
@@ -28,7 +28,7 @@
private boolean m_readOnly;
/**
* Construct ComponentLocator with no parent.
*
*/
public DefaultComponentManager()
@@ -37,7 +37,7 @@
}
/**
* Construct ComponentLocator with specified parent.
*
* @param parent the ComponentManagers parent
*/
@@ -47,7 +47,7 @@
}
/**
* Retrieve Component by role from ComponentLocator.
*
* @param role the role
* @return the Component
@@ -97,7 +97,7 @@
}
/**
* Place Component into ComponentLocator.
*
* @param role the components role
* @param component the component
@@ -115,14 +115,14 @@
*/
public void release( final Component component )
{
- // if the ComponentLocator handled pooling, it would be
+ // if the ComponentManager handled pooling, it would be
// returned to the pool here.
}
/**
* Build a human readable representation of ComponentLocator.
*
* @return the description of ComponentLocator
*/
public String toString()
{
@@ -143,7 +143,7 @@
/**
* Helper method for subclasses to retrieve parent.
*
* @return the parent ComponentLocator
*/
protected final ComponentManager getParent()
{
@@ -179,7 +179,7 @@
if( m_readOnly )
{
throw new IllegalStateException
- ( "ComponentLocator is read only and can not be modified" );
+ ( "ComponentManager is read only and can not be modified" );
}
}
}
@@ -28,7 +28,7 @@
private boolean m_readOnly;
/**
- * Construct ComponentLocator with no parent.
+ * Construct ComponentManager with no parent.
*
*/
@@ -37,7 +37,7 @@
}
/**
- * Construct ComponentLocator with specified parent.
+ * Construct ComponentManager with specified parent.
*
* @param parent the ComponentManagers parent
@@ -47,7 +47,7 @@
}
/**
- * Retrieve Component by role from ComponentLocator.
+ * Retrieve Component by role from ComponentManager.
*
* @param role the role
@@ -97,7 +97,7 @@
}
/**
- * Place Component into ComponentLocator.
+ * Place Component into ComponentManager.
*
* @param role the components role
@@ -115,14 +115,14 @@
}
/**
- * Build a human readable representation of ComponentLocator.
+ * Build a human readable representation of ComponentManager.
*
@@ -115,14 +115,14 @@
*
- * @return the description of ComponentLocator
+ * @return the description of ComponentManager
*/
public String toString()
@@ -143,7 +143,7 @@
* Helper method for subclasses to retrieve parent.
*
- * @return the parent ComponentLocator
+ * @return the parent ComponentManager
*/
protected final ComponentManager getParent()
1.10 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentSelector.java
Index: DefaultComponentManagerTestCase.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/test/org/apache/avalon/framework/component/test/DefaultComponentManagerTestCase.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DefaultComponentManagerTestCase.java 14 Jun 2002 01:55:52 -0000
1.3
+++ DefaultComponentManagerTestCase.java 14 Jun 2002 13:04:03 -0000
1.4
@@ -45,7 +45,7 @@
public DefaultComponentManagerTestCase()
{
- this("DefaultComponentLocator Test Case");
+ this("DefaultComponentManager Test Case");
}
public DefaultComponentManagerTestCase( final String name )
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>